==> react-hr-component-kc-1.0.58.tgz: package/src/components/OnboardPlanetOrgTest.js <==
import React, { useState, useEffect } from "react";
import ReactDOM from "react-dom";
//import Button from "@material-ui/core/Button";
import { useLocation } from "react-router-dom";
import { Form, Row, Col, Button } from "react-bootstrap";
import axios from "axios";

function OnboardPlanetOrgTest(props) {
  const location = useLocation();

  const [planetOrgEnvHostData, setPlanetOrgEnvHostData] = useState({
    orgName: "",
    credential: "",
    env: [
      {
        name: "",
        vhost: [
          {
            envName: "",
            name: "",
            protocol: "",
            port: "",
            cname: "",
          },
        ],
      },
    ],
  });

  //add environment
  const addEnvironment = (e) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env.push({
      name: "",
      vhost: [
        {
          envName: "",
          name: "",
          protocol: "",
          port: "",
          cname: "",
        },
      ],
    });
    setPlanetOrgEnvHostData(temp);
  };

  //add vhost
  const addVhost = (e, i) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost.push({
      envName: "",
      name: "",
      protocol: "",
      port: "",
      cname: "",
    });
    setPlanetOrgEnvHostData(temp);
  };

  //remove environment
  const deleteEnvironment = (e, i) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env.splice(i, 1);
    setPlanetOrgEnvHostData(temp);
  };

  //remove vhost
  const deleteVhost = (e, i, j) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost.splice(j, 1);
    setPlanetOrgEnvHostData(temp);
  };

  //planet org name change
  const handleOrgNameChange = (e) => {
    let temp = { ...planetOrgEnvHostData };
    temp[e.target.name] = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //planet org credential change
  const handleOrgCredentialChange = (e) => {
    let temp = { ...planetOrgEnvHostData };
    temp[e.target.name] = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //environment name change
  const handleEnvironmentNameChange = (e, i) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i][e.target.name] = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //vhost name change
  const handleVhostNameChange = (e, i, j) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost[j].name = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //vhost envName change
  const handleVhostEnvNameChange = (e, i, j) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost[j].envName = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //vhost protocol change
  const handleVhostProtocolChange = (e, i, j) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost[j].protocol = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //vhost port change
  const handleVhostPortChange = (e, i, j) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost[j].port = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //vhost cname change
  const handleVhostCnameChange = (e, i, j) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost[j].cname = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  const onboardPlantOrgSubmitHandler = (e) => {
    console.log(planetOrgEnvHostData);
  };

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Onboard Org</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/">Onboard Org</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">{props.leftNavigation}</div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div className="mb-3">
                      <Form>
                        <Form.Group as={Row} controlId="onboardOrgName">
                          <Form.Label column sm={2}>
                            Org Name <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="orgName"
                              onChange={handleOrgNameChange}
                              value={planetOrgEnvHostData.orgName}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="onboardOrgCredential">
                          <Form.Label column sm={2}>
                            Credential <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="credential"
                              onChange={handleOrgCredentialChange}
                              value={planetOrgEnvHostData.credential}
                            />
                          </Col>
                        </Form.Group>
                        <p>
                          <strong>Add Environment(s):</strong>
                        </p>
                        {planetOrgEnvHostData.env.map((envts, i) => (
                          <div className="group-field-highlight-pattern-info">
                            <Form.Group
                              as={Row}
                              controlId="onboardOrgEnvironmentName"
                            >
                              <Form.Label column sm={2}>
                                Name <span className="required">*</span>
                              </Form.Label>
                              <Col sm={10}>
                                <div className="row org-button">
                                  <Form.Control
                                    type="text"
                                    className="w-75"
                                    name="name"
                                    onChange={(e) =>
                                      handleEnvironmentNameChange(e, i)
                                    }
                                    value={planetOrgEnvHostData.env[i].name}
                                  />
                                  <Button
                                    variant="secondary"
                                    onClick={(e) => deleteEnvironment(e, i)}
                                  >
                                    -Env
                                  </Button>
                                </div>
                              </Col>
                            </Form.Group>

                            <p>
                              <strong>VHost(s)(s):</strong>
                            </p>
                            {envts.vhost.map((host, j) => (
                              <div className="group-field-highlight-org-info">
                                <Form.Group
                                  as={Row}
                                  controlId="onboardOrgVhostname"
                                >
                                  <Form.Label column sm={2}>
                                    Name <span className="required">*</span>
                                  </Form.Label>
                                  <Col sm={10}>
                                    <div className="row org-button">
                                      <Form.Control
                                        type="text"
                                        className="w-75"
                                        name="name"
                                        onChange={(e) =>
                                          handleVhostNameChange(e, i, j)
                                        }
                                        value={
                                          planetOrgEnvHostData.env[i].vhost[j]
                                            .name
                                        }
                                      />
                                      <Button
                                        variant="secondary"
                                        onClick={(e) => deleteVhost(e, i, j)}
                                      >
                                        -Vhost
                                      </Button>
                                    </div>
                                  </Col>
                                </Form.Group>
                                <Form.Group
                                  as={Row}
                                  controlId="onboardOrgVhostEnvName"
                                >
                                  <Form.Label column sm={2}>
                                    envName <span className="required">*</span>
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      type="text"
                                      className="w-75"
                                      name="envName"
                                      onChange={(e) =>
                                        handleVhostEnvNameChange(e, i, j)
                                      }
                                      value={
                                        planetOrgEnvHostData.env[i].vhost[j]
                                          .envName
                                      }
                                    />
                                  </Col>
                                </Form.Group>
                                <Form.Group
                                  as={Row}
                                  controlId="onboardOrgVhostProtocol"
                                >
                                  <Form.Label column sm={2}>
                                    Protocol <span className="required">*</span>
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      type="text"
                                      className="w-75"
                                      name="protocol"
                                      onChange={(e) =>
                                        handleVhostProtocolChange(e, i, j)
                                      }
                                      value={
                                        planetOrgEnvHostData.env[i].vhost[j]
                                          .protocol
                                      }
                                    />
                                  </Col>
                                </Form.Group>
                                <Form.Group
                                  as={Row}
                                  controlId="onboardOrgVhostPort"
                                >
                                  <Form.Label column sm={2}>
                                    Port <span className="required">*</span>
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      type="text"
                                      className="w-75"
                                      name="port"
                                      onChange={(e) =>
                                        handleVhostPortChange(e, i, j)
                                      }
                                      value={
                                        planetOrgEnvHostData.env[i].vhost[j]
                                          .port
                                      }
                                    />
                                  </Col>
                                </Form.Group>
                                <Form.Group
                                  as={Row}
                                  controlId="onboardOrgVhostCname"
                                >
                                  <Form.Label column sm={2}>
                                    Cname <span className="required">*</span>
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      type="text"
                                      className="w-75"
                                      name="cname"
                                      onChange={(e) =>
                                        handleVhostCnameChange(e, i, j)
                                      }
                                      value={
                                        planetOrgEnvHostData.env[i].vhost[j]
                                          .cname
                                      }
                                    />
                                  </Col>
                                </Form.Group>
                              </div>
                            ))}
                            <Button
                              variant="primary"
                              onClick={(e) => addVhost(e, i)}
                            >
                              +Vhost
                            </Button>
                          </div>
                        ))}
                      </Form>
                      <Button variant="primary" onClick={addEnvironment}>
                        +Env
                      </Button>{" "}
                      <br />
                      <br />
                      <Button
                        variant="primary"
                        onClick={onboardPlantOrgSubmitHandler}
                      >
                        Create
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default OnboardPlanetOrgTest;

==> react-hr-component-kc-1.0.59.tgz: package/src/components/OnboardPlanetOrgTest.js <==
import React, { useState, useEffect } from "react";
import ReactDOM from "react-dom";
//import Button from "@material-ui/core/Button";
import { useLocation } from "react-router-dom";
import { Form, Row, Col, Button } from "react-bootstrap";
import axios from "axios";

function OnboardPlanetOrgTest(props) {
  const location = useLocation();

  const [planetOrgEnvHostData, setPlanetOrgEnvHostData] = useState({
    orgName: "",
    credential: "",
    env: [
      {
        name: "",
        vhost: [
          {
            envName: "",
            name: "",
            protocol: "",
            port: "",
            cname: "",
          },
        ],
      },
    ],
  });

  //add environment
  const addEnvironment = (e) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env.push({
      name: "",
      vhost: [
        {
          envName: "",
          name: "",
          protocol: "",
          port: "",
          cname: "",
        },
      ],
    });
    setPlanetOrgEnvHostData(temp);
  };

  //add vhost
  const addVhost = (e, i) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost.push({
      envName: "",
      name: "",
      protocol: "",
      port: "",
      cname: "",
    });
    setPlanetOrgEnvHostData(temp);
  };

  //remove environment
  const deleteEnvironment = (e, i) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env.splice(i, 1);
    setPlanetOrgEnvHostData(temp);
  };

  //remove vhost
  const deleteVhost = (e, i, j) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost.splice(j, 1);
    setPlanetOrgEnvHostData(temp);
  };

  //planet org name change
  const handleOrgNameChange = (e) => {
    let temp = { ...planetOrgEnvHostData };
    temp[e.target.name] = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //planet org credential change
  const handleOrgCredentialChange = (e) => {
    let temp = { ...planetOrgEnvHostData };
    temp[e.target.name] = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //environment name change
  const handleEnvironmentNameChange = (e, i) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i][e.target.name] = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //vhost name change
  const handleVhostNameChange = (e, i, j) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost[j].name = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //vhost envName change
  const handleVhostEnvNameChange = (e, i, j) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost[j].envName = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //vhost protocol change
  const handleVhostProtocolChange = (e, i, j) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost[j].protocol = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //vhost port change
  const handleVhostPortChange = (e, i, j) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost[j].port = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  //vhost cname change
  const handleVhostCnameChange = (e, i, j) => {
    let temp = { ...planetOrgEnvHostData };
    temp.env[i].vhost[j].cname = e.target.value;
    setPlanetOrgEnvHostData(temp);
  };

  const onboardPlantOrgSubmitHandler = (e) => {
    console.log(planetOrgEnvHostData);
    axios
      .post(
        `https://configurator-api-m7mkmev5sq-uc.a.run.app/planet/${new URLSearchParams(
          location.search
        ).get("planetId")}/orgs`,
        planetOrgEnvHostData
      )
      .then((res) => {
        console.log(res);
      })
      .catch((err) => {
        console.log(err.message);
      });
  };

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Onboard Org</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/">Onboard Org</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">{props.leftNavigation}</div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div className="mb-3">
                      <Form>
                        <Form.Group as={Row} controlId="onboardOrgName">
                          <Form.Label column sm={2}>
                            Org Name <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="orgName"
                              onChange={handleOrgNameChange}
                              value={planetOrgEnvHostData.orgName}
                            />
                          </Col>
                        </Form.Group>
                        <Form.Group as={Row} controlId="onboardOrgCredential">
                          <Form.Label column sm={2}>
                            Credential <span className="required">*</span>
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="credential"
                              onChange={handleOrgCredentialChange}
                              value={planetOrgEnvHostData.credential}
                            />
                          </Col>
                        </Form.Group>
                        <p>
                          <strong>Add Environment(s):</strong>
                        </p>
                        {planetOrgEnvHostData.env.map((envts, i) => (
                          <div className="group-field-highlight-pattern-info">
                            <Form.Group
                              as={Row}
                              controlId="onboardOrgEnvironmentName"
                            >
                              <Form.Label column sm={2}>
                                Name <span className="required">*</span>
                              </Form.Label>
                              <Col sm={10}>
                                <div className="row org-button">
                                  <Form.Control
                                    type="text"
                                    className="w-75"
                                    name="name"
                                    onChange={(e) =>
                                      handleEnvironmentNameChange(e, i)
                                    }
                                    value={planetOrgEnvHostData.env[i].name}
                                  />
                                  <Button
                                    variant="secondary"
                                    onClick={(e) => deleteEnvironment(e, i)}
                                  >
                                    -Env
                                  </Button>
                                </div>
                              </Col>
                            </Form.Group>

                            <p>
                              <strong>VHost(s):</strong>
                            </p>
                            {envts.vhost.map((host, j) => (
                              <div className="group-field-highlight-org-info">
                                <Form.Group
                                  as={Row}
                                  controlId="onboardOrgVhostname"
                                >
                                  <Form.Label column sm={2}>
                                    Name <span className="required">*</span>
                                  </Form.Label>
                                  <Col sm={10}>
                                    <div className="row org-button">
                                      <Form.Control
                                        type="text"
                                        className="w-75"
                                        name="name"
                                        onChange={(e) =>
                                          handleVhostNameChange(e, i, j)
                                        }
                                        value={
                                          planetOrgEnvHostData.env[i].vhost[j]
                                            .name
                                        }
                                      />
                                      <Button
                                        variant="secondary"
                                        onClick={(e) => deleteVhost(e, i, j)}
                                      >
                                        -Vhost
                                      </Button>
                                    </div>
                                  </Col>
                                </Form.Group>
                                <Form.Group
                                  as={Row}
                                  controlId="onboardOrgVhostEnvName"
                                >
                                  <Form.Label column sm={2}>
                                    envName <span className="required">*</span>
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      type="text"
                                      className="w-75"
                                      name="envName"
                                      onChange={(e) =>
                                        handleVhostEnvNameChange(e, i, j)
                                      }
                                      value={
                                        planetOrgEnvHostData.env[i].vhost[j]
                                          .envName
                                      }
                                    />
                                  </Col>
                                </Form.Group>
                                <Form.Group
                                  as={Row}
                                  controlId="onboardOrgVhostProtocol"
                                >
                                  <Form.Label column sm={2}>
                                    Protocol <span className="required">*</span>
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      type="text"
                                      className="w-75"
                                      name="protocol"
                                      onChange={(e) =>
                                        handleVhostProtocolChange(e, i, j)
                                      }
                                      value={
                                        planetOrgEnvHostData.env[i].vhost[j]
                                          .protocol
                                      }
                                    />
                                  </Col>
                                </Form.Group>
                                <Form.Group
                                  as={Row}
                                  controlId="onboardOrgVhostPort"
                                >
                                  <Form.Label column sm={2}>
                                    Port <span className="required">*</span>
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      type="text"
                                      className="w-75"
                                      name="port"
                                      onChange={(e) =>
                                        handleVhostPortChange(e, i, j)
                                      }
                                      value={
                                        planetOrgEnvHostData.env[i].vhost[j]
                                          .port
                                      }
                                    />
                                  </Col>
                                </Form.Group>
                                <Form.Group
                                  as={Row}
                                  controlId="onboardOrgVhostCname"
                                >
                                  <Form.Label column sm={2}>
                                    Cname <span className="required">*</span>
                                  </Form.Label>
                                  <Col sm={10}>
                                    <Form.Control
                                      type="text"
                                      className="w-75"
                                      name="cname"
                                      onChange={(e) =>
                                        handleVhostCnameChange(e, i, j)
                                      }
                                      value={
                                        planetOrgEnvHostData.env[i].vhost[j]
                                          .cname
                                      }
                                    />
                                  </Col>
                                </Form.Group>
                              </div>
                            ))}
                            <Button
                              variant="primary"
                              onClick={(e) => addVhost(e, i)}
                            >
                              +Vhost
                            </Button>
                          </div>
                        ))}
                      </Form>
                      <Button variant="primary" onClick={addEnvironment}>
                        +Env
                      </Button>{" "}
                      <br />
                      <br />
                      <Button
                        variant="primary"
                        onClick={onboardPlantOrgSubmitHandler}
                      >
                        Create
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default OnboardPlanetOrgTest;
